@@ -10,7 +10,6 @@ from __future__ import absolute_import, division, print_function
 import torch
 import torch.nn.functional as F
 from ..encoders.squeeze_extractor import *
-from .model_utils import *
 
 class PSPModule(nn.Module):
     def __init__(self, in_channels, out_channels=1024, pool_factors=(1, 2, 3, 6), batch_norm=True):
@@ -23,7 +22,7 @@ class PSPModule(nn.Module):
         bottleneck = []
         bottleneck += [nn.Conv2d(in_channels * (len(pool_factors) + 1), out_channels, kernel_size=1)]
         if batch_norm:
-            bottleneck += nn.BatchNorm2d(out_channels)
+            bottleneck += [nn.BatchNorm2d(out_channels)]
         bottleneck += [nn.ReLU(inplace=True)]
         self.bottleneck = nn.Sequential(*bottleneck)
 
@@ -32,7 +31,7 @@ class PSPModule(nn.Module):
         spatial_block += [nn.AdaptiveAvgPool2d(output_size=(pool_factor, pool_factor))]
         spatial_block += [nn.Conv2d(in_channels, in_channels, kernel_size=1, bias=False)]
         if batch_norm:
-            spatial_block += nn.BatchNorm2d(in_channels)
+            spatial_block += [nn.BatchNorm2d(in_channels)]
         spatial_block += [nn.ReLU(inplace=True)]
 
         return nn.Sequential(*spatial_block)
@@ -63,7 +62,7 @@ class PSPUpsampling(nn.Module):
         layers = []
         layers += [nn.Conv2d(in_channels, out_channels, kernel_size=3, padding=1)]
         if batch_norm:
-            layers += nn.BatchNorm2d(out_channels)
+            layers += [nn.BatchNorm2d(out_channels)]
         layers += [nn.ReLU(inplace=True)]
         self.layer = nn.Sequential(*layers)
 
@@ -129,11 +128,8 @@ class PSPnet(torch.nn.Module):
         o = self.upsampling2(o)
         o = self.upsampling3(o)
 
-        cx = int((o.shape[3] - x.shape[3]) / 2)
-        cy = int((o.shape[2] - x.shape[2]) / 2)
-        o = o[:, :, cy:cy + x.shape[2], cx:cx + x.shape[3]]
+        o = F.upsample(o, size=(x.shape[2], x.shape[3]), mode='bilinear')
         o = self.classifier(o)
-        set_segmentation_model_params(self, x.shape[3], x.shape[2])
 
         return o
 
@@ -141,63 +137,73 @@ from ..encoders.vgg import *
 from ..encoders.resnet import *
 from ..encoders.mobilenet import *
 
-def pspnet_vgg11(n_classes, batch_norm=True, pretrained=False, fixed_feature=True):
+def pspnet_vgg11(n_classes, batch_size, pretrained=False, fixed_feature=True):
+    batch_norm = False if batch_size == 1 else True
     vgg = vgg_11(batch_norm, pretrained, fixed_feature)
     copy_feature_info = vgg.get_copy_feature_info()
     squeeze_feature_idx = copy_feature_info[3].index - 1
     vgg.features = vgg.features[:squeeze_feature_idx]
     return PSPnet(n_classes, vgg, batch_norm)
-def pspnet_vgg13(n_classes, batch_norm=True, pretrained=False, fixed_feature=True):
+def pspnet_vgg13(n_classes, batch_size, pretrained=False, fixed_feature=True):
+    batch_norm = False if batch_size == 1 else True
     vgg = vgg_13(batch_norm, pretrained, fixed_feature)
     copy_feature_info = vgg.get_copy_feature_info()
     squeeze_feature_idx = copy_feature_info[3].index - 1
     vgg.features = vgg.features[:squeeze_feature_idx]
     return PSPnet(n_classes, vgg, batch_norm)
-def pspnet_vgg16(n_classes, batch_norm=True, pretrained=False, fixed_feature=True):
+def pspnet_vgg16(n_classes, batch_size, pretrained=False, fixed_feature=True):
+    batch_norm = False if batch_size == 1 else True
     vgg = vgg_16(batch_norm, pretrained, fixed_feature)
     copy_feature_info = vgg.get_copy_feature_info()
     squeeze_feature_idx = copy_feature_info[3].index - 1
     vgg.features = vgg.features[:squeeze_feature_idx]
     return PSPnet(n_classes, vgg, batch_norm)
-def pspnet_vgg19(n_classes, batch_norm=True, pretrained=False, fixed_feature=True):
+def pspnet_vgg19(n_classes, batch_size, pretrained=False, fixed_feature=True):
+    batch_norm = False if batch_size == 1 else True
     vgg = vgg_19(batch_norm, pretrained, fixed_feature)
     copy_feature_info = vgg.get_copy_feature_info()
     squeeze_feature_idx = copy_feature_info[3].index - 1
     vgg.features = vgg.features[:squeeze_feature_idx]
     return PSPnet(n_classes, vgg, batch_norm)
 
-def pspnet_resnet18(n_classes, batch_norm=True, pretrained=False, fixed_feature=True):
+def pspnet_resnet18(n_classes, batch_size, pretrained=False, fixed_feature=True):
+    batch_norm = False if batch_size == 1 else True
     resnet = resnet18(pretrained, fixed_feature)
     copy_feature_info = resnet.get_copy_feature_info()
     squeeze_feature_idx = copy_feature_info[3].index
     resnet.features = resnet.features[:squeeze_feature_idx]
     return PSPnet(n_classes, resnet, batch_norm)
-def pspnet_resnet34(n_classes, batch_norm=True, pretrained=False, fixed_feature=True):
+def pspnet_resnet34(n_classes, batch_size, pretrained=False, fixed_feature=True):
+    batch_norm = False if batch_size == 1 else True
     resnet = resnet34(pretrained, fixed_feature)
     copy_feature_info = resnet.get_copy_feature_info()
     squeeze_feature_idx = copy_feature_info[3].index
     resnet.features = resnet.features[:squeeze_feature_idx]
     return PSPnet(n_classes, resnet, batch_norm)
-def pspnet_resnet50(n_classes, batch_norm=True, pretrained=False, fixed_feature=True):
+def pspnet_resnet50(n_classes, batch_size, pretrained=False, fixed_feature=True):
+    batch_norm = False if batch_size == 1 else True
     resnet = resnet50(pretrained, fixed_feature)
     copy_feature_info = resnet.get_copy_feature_info()
     squeeze_feature_idx = copy_feature_info[3].index
     resnet.features = resnet.features[:squeeze_feature_idx]
     return PSPnet(n_classes, resnet, batch_norm)
-def pspnet_resnet101(n_classes, batch_norm=True, pretrained=False, fixed_feature=True):
+def pspnet_resnet101(n_classes, batch_size, pretrained=False, fixed_feature=True):
+    batch_norm = False if batch_size == 1 else True
     resnet = resnet101(pretrained, fixed_feature)
     copy_feature_info = resnet.get_copy_feature_info()
     squeeze_feature_idx = copy_feature_info[3].index
     resnet.features = resnet.features[:squeeze_feature_idx]
     return PSPnet(n_classes, resnet, batch_norm)
-def pspnet_resnet152(n_classes, batch_norm=True, pretrained=False, fixed_feature=True):
+def pspnet_resnet152(n_classes, batch_size, pretrained=False, fixed_feature=True):
+    batch_norm = False if batch_size == 1 else True
     resnet = resnet152(pretrained, fixed_feature)
     copy_feature_info = resnet.get_copy_feature_info()
     squeeze_feature_idx = copy_feature_info[3].index
     resnet.features = resnet.features[:squeeze_feature_idx]
     return PSPnet(n_classes, resnet, batch_norm)
 
-def pspnet_mobilenet_v2(n_classes, batch_norm=True, pretrained=False, fixed_feature=True):
+def pspnet_mobilenet_v2(n_classes, batch_size, pretrained=False, fixed_feature=True):
+    batch_norm = False if batch_size == 1 else True
     mobile_net = mobilenet(pretrained, fixed_feature)
     copy_feature_info = mobile_net.get_copy_feature_info()
     squeeze_feature_idx = copy_feature_info[3].index
