@@ -9,7 +9,6 @@ from __future__ import absolute_import, division, print_function
 
 import torch
 from ..encoders.squeeze_extractor import *
-from .model_utils import *
 
 class UnetWithEncoder(torch.nn.Module):
 
@@ -55,7 +54,7 @@ class UnetWithEncoder(torch.nn.Module):
 
     def _make_up_sampling(self, cfi_idx):
         if cfi_idx == -1:
-            in_channels = self._get_last_out_channels(self.features[:-1])
+            in_channels = self._get_last_out_channels(self.features)
         else:
             in_channels = self.copy_feature_info[cfi_idx + 1].out_channels
 
@@ -138,8 +137,6 @@ class UnetWithEncoder(torch.nn.Module):
         o = self.up_layer4(o)
         o = self.classifier(o)
 
-        set_segmentation_model_params(self, x.shape[3], x.shape[2])
-
         return o
 
 cfgs = {
@@ -206,7 +203,6 @@ class Unet(torch.nn.Module):
         cy = int((o.shape[2] - x.shape[2]) / 2)
         o = o[:, :, cy:cy + x.shape[2], cx:cx + x.shape[3]]
         o = self.classifier(o)
-        set_segmentation_model_params(self, x.shape[3], x.shape[2])
 
         return o
 
@@ -214,39 +210,50 @@ from ..encoders.vgg import *
 from ..encoders.resnet import *
 from ..encoders.mobilenet import *
 
-def unet_vgg11(n_classes, batch_norm=True, pretrained=False, fixed_feature=True):
+def unet_vgg11(n_classes, batch_size, pretrained=False, fixed_feature=True):
+    batch_norm = False if batch_size == 1 else True
     vgg = vgg_11(batch_norm, pretrained, fixed_feature)
     return UnetWithEncoder(n_classes, vgg, batch_norm)
-def unet_vgg13(n_classes, batch_norm=True, pretrained=False, fixed_feature=True):
+def unet_vgg13(n_classes, batch_size, pretrained=False, fixed_feature=True):
+    batch_norm = False if batch_size == 1 else True
     vgg = vgg_13(batch_norm, pretrained, fixed_feature)
     return UnetWithEncoder(n_classes, vgg, batch_norm)
-def unet_vgg16(n_classes, batch_norm=True, pretrained=False, fixed_feature=True):
+def unet_vgg16(n_classes, batch_size, pretrained=False, fixed_feature=True):
+    batch_norm = False if batch_size == 1 else True
     vgg = vgg_16(batch_norm, pretrained, fixed_feature)
     return UnetWithEncoder(n_classes, vgg, batch_norm)
-def unet_vgg19(n_classes, batch_norm=True, pretrained=False, fixed_feature=True):
+def unet_vgg19(n_classes, batch_size, pretrained=False, fixed_feature=True):
+    batch_norm = False if batch_size == 1 else True
     vgg = vgg_19(batch_norm, pretrained, fixed_feature)
     return UnetWithEncoder(n_classes, vgg, batch_norm)
 
-def unet_resnet18(n_classes, batch_norm=True, pretrained=False, fixed_feature=True):
+def unet_resnet18(n_classes, batch_size, pretrained=False, fixed_feature=True):
+    batch_norm = False if batch_size == 1 else True
     resnet = resnet18(pretrained, fixed_feature)
     return UnetWithEncoder(n_classes, resnet, batch_norm)
-def unet_resnet34(n_classes, batch_norm=True, pretrained=False, fixed_feature=True):
+def unet_resnet34(n_classes, batch_size, pretrained=False, fixed_feature=True):
+    batch_norm = False if batch_size == 1 else True
     resnet = resnet34(pretrained, fixed_feature)
     return UnetWithEncoder(n_classes, resnet, batch_norm)
-def unet_resnet50(n_classes, batch_norm=True, pretrained=False, fixed_feature=True):
+def unet_resnet50(n_classes, batch_size, pretrained=False, fixed_feature=True):
+    batch_norm = False if batch_size == 1 else True
     resnet = resnet50(pretrained, fixed_feature)
     return UnetWithEncoder(n_classes, resnet, batch_norm)
-def unet_resnet101(n_classes, batch_norm=True, pretrained=False, fixed_feature=True):
+def unet_resnet101(n_classes, batch_size, pretrained=False, fixed_feature=True):
+    batch_norm = False if batch_size == 1 else True
     resnet = resnet101(pretrained, fixed_feature)
     return UnetWithEncoder(n_classes, resnet, batch_norm)
-def unet_resnet152(n_classes, batch_norm=True, pretrained=False, fixed_feature=True):
+def unet_resnet152(n_classes, batch_size, pretrained=False, fixed_feature=True):
+    batch_norm = False if batch_size == 1 else True
     resnet = resnet152(pretrained, fixed_feature)
     return UnetWithEncoder(n_classes, resnet, batch_norm)
 
-def unet_mobilenet_v2(n_classes, batch_norm=True, pretrained=False, fixed_feature=True):
+def unet_mobilenet_v2(n_classes, batch_size, pretrained=False, fixed_feature=True):
+    batch_norm = False if batch_size == 1 else True
     mobile_net = mobilenet(pretrained, fixed_feature)
     return UnetWithEncoder(n_classes, mobile_net, batch_norm)
 
-def unet(n_classes, batch_norm=True):
+def unet(n_classes, batch_size):
+    batch_norm = False if batch_size == 1 else True
     return Unet(n_classes, cfgs['A'], batch_norm)
 
